function [] = example(method, dataset_name, m, flag, d_num, Runs)
% Example on how to invoke the CRAFT function. 

warning('off', 'all');
if nargin < 6, Runs = 20; end
if nargin < 5, d_num = 0; end
if nargin < 3, m = 0.5; end     

rho = m*(1-m) - 0.01;
MaxIter = 100;
data = csvread(dataset_name);

% For the example datasets (spam, splice), labels are provided in the last column 
x = data(:, 1:end-1);      
y = data(:, end);

% Convert the splice dataset into binary
if flag == 1  
   x(x==1.0) = 0;
   x(x==2.0) = 0;
   x(x==3.0) = 1;
   x(x==4.0) = 1;
end

% Compute scores
if strncmp(method, 'Binary', 6)    % all features binary categorical 
   for i=1:Runs                    % perform independent runs
       [z, ~, K_plus] = CRAFT(x, 0.1, 0, m, rho, MaxIter, i, numel(unique(y)));
       Purity_CRAFT(i) = purity(z, y, K_plus);
       NMI_CRAFT(i) = nmi(z, y); 
   end   
elseif strncmp(method, 'Mix', 3)  % assorted features 
    for i=1:20
        [z, ~, K_plus] = CRAFT(x, 0.1, d_num, m, rho, MaxIter, i, numel(unique(y)));
        Purity_CRAFT(i) = purity(z, y, K_plus);
        NMI_CRAFT(i) = nmi(z, y);
    end
else                              % all features numeric
   for i=1:20
       [z, ~, K_plus] = CRAFT(x, 0.1, size(x, 2), m, rho, MaxIter, i, numel(unique(y)));
        Purity_CRAFT(i) = purity(z, y, K_plus);
        NMI_CRAFT(i) = nmi(z, y);
   end 
end


Mean_Purity = mean(Purity_CRAFT);
Mean_NMI = mean(NMI_CRAFT);
%Std_Purity = std(Purity_CRAFT);     
%Std_NMI = std(NMI_CRAFT);

rd=2;                              % number of decimal digits scores are rounded to
Mean_Purity=round(Mean_Purity*10^rd)./10^rd;
Mean_NMI=round(Mean_NMI*10^rd)./10^rd;
%Std_Purity=round(Std_Purity*10^rd)./10^rd;
%Std_NMI=round(Std_NMI*10^rd)./10^rd;

fprintf('\nDataset = %s, m = %.1f: purity = %.2f, nmi = %.2f \n', dataset_name, m, Mean_Purity, Mean_NMI);



 



